@@ -903,6 +903,7 @@ parse_ignore_host (gpointer data, gpointer user_data)
 		/* It is a hostname. */
 		gl_ignore_hosts = g_slist_append (gl_ignore_hosts, hostname);
 		DEBUG_HTTP (("Host %s does not go through proxy.", hostname));
+		g_free (elt);
 	}
 }
 
@@ -1713,7 +1714,7 @@ do_create (GnomeVFSMethod *method,
 	 * playing with LOCK, but mod_dav cannot. */
 	HttpFileHandle *handle;
 	GnomeVFSResult result;
-	GByteArray *bytes = g_byte_array_new();
+	GByteArray *bytes;
 	
 	ANALYZE_HTTP ("==> +do_create");
 	DEBUG_HTTP (("+Create URI: '%s'", gnome_vfs_uri_get_path (uri)));
@@ -1743,10 +1744,11 @@ do_create (GnomeVFSMethod *method,
 	}
 	
 	ANALYZE_HTTP ("==> Creating initial file");
-	
+	bytes  = g_byte_array_new();
       	result = make_request (&handle, uri, "PUT", bytes, NULL, context);
 	http_handle_close(handle, context);
-	
+	g_byte_array_free (bytes, TRUE);
+		
 	if (result != GNOME_VFS_OK) {
 		/* the PUT failed */
 		
@@ -1765,9 +1767,6 @@ do_create (GnomeVFSMethod *method,
 		return result;
 	}
 
-	/* clean up */
-	g_byte_array_free (bytes, TRUE);
-	
 	/* FIXME bugzilla.gnome.org 41159: do we need to do something more intelligent here? */
 	result = do_open (method, method_handle, uri, GNOME_VFS_OPEN_WRITE, context);
 
@@ -1902,7 +1901,25 @@ do_read (GnomeVFSMethod *method,
 	return result;
 }
 
+
 /* Directory handling - WebDAV servers only */
+static void
+process_resourcetype_node (GnomeVFSFileInfo *file_info, xmlNodePtr node)
+{
+	xmlNodePtr it;
+	
+	file_info->valid_fields |= 
+		GNOME_VFS_FILE_INFO_FIELDS_TYPE;
+	file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
+	
+	for (it = node->xmlChildrenNode; it != NULL; it = it->next) {
+		if ((!xmlIsBlankNode (it))
+		    && (it->name != NULL)
+		    && (strcmp (it->name, "collection") == 0)) {
+			file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
+		}
+	}
+}
 
 static void
 process_propfind_propstat (xmlNodePtr node, 
@@ -1950,14 +1967,7 @@ process_propfind_propstat (xmlNodePtr node,
 				node_content_xml = NULL;
 			}
 			if (strcmp ((char *)l->name, "resourcetype") == 0) {
-				file_info->valid_fields |= 
-					GNOME_VFS_FILE_INFO_FIELDS_TYPE;
-				file_info->type = GNOME_VFS_FILE_TYPE_REGULAR;
-				
-				if (l->xmlChildrenNode && l->xmlChildrenNode->name 
-				    && strcmp ((char *)l->xmlChildrenNode->name, "collection") == 0) {
-					file_info->type = GNOME_VFS_FILE_TYPE_DIRECTORY;
-				}
+				process_resourcetype_node (file_info, l);
 			}
 			l = l->next;
 		}
@@ -2207,6 +2217,13 @@ make_propfind_request (HttpFileHandle **handle_return,
 		DEBUG_HTTP (("HTTP server returned an invalid PROPFIND response: %d", (*handle_return)->server_status));
 		result = GNOME_VFS_ERROR_NOT_SUPPORTED;
 	}
+	/* Some servers (download.microsoft.com) will just close
+	 * the connection (EOF) without returning any HTTP status.
+	 */
+	if (result == GNOME_VFS_ERROR_EOF) {
+		DEBUG_HTTP (("HTTP server returned an empty PROPFIND response"));
+		result = GNOME_VFS_ERROR_NOT_SUPPORTED;
+	}
 	
 	if (result == GNOME_VFS_OK) {
 		do {
@@ -2236,7 +2253,20 @@ make_propfind_request (HttpFileHandle **handle_return,
 		result = GNOME_VFS_ERROR_GENERIC;
 		goto cleanup;
 	}
-	
+
+#if 0
+	/* Enable this block of code if you want to dump the xml answer
+	 * sent by the server 
+	 */
+	{
+		xmlChar *query_result;
+		int result_len;
+		xmlDocDumpMemory (doc, &query_result, &result_len);
+		g_print ("propfind query result: %s\n", query_result);
+		g_free (query_result);
+	}	
+#endif
+
 	cur = doc->xmlRootNode;
 	if (strcmp ((char *)cur->name, "multistatus") != 0) {
 		DEBUG_HTTP (("Couldn't find <multistatus>.\n"));
@@ -2304,6 +2334,7 @@ make_propfind_request (HttpFileHandle **handle_return,
 cleanup:
 	g_free(buffer);
 	g_free(extraheaders);
+	g_byte_array_free (request, TRUE);
 	xmlFreeParserCtxt(parserContext);
 	
 	if (result != GNOME_VFS_OK) {
@@ -2505,6 +2536,7 @@ do_get_file_info (GnomeVFSMethod *method,
 					gnome_vfs_file_info_copy (file_info, handle->file_info);
 					http_cache_add_uri (uri, handle->file_info, FALSE);
 					http_handle_close (handle, context);
+					handle = NULL;
 				}
 
 				/* If we get a redirect, we should be
@@ -2692,6 +2724,7 @@ do_move (GnomeVFSMethod *method,
 
 	result = make_request (&handle, old_uri, "MOVE", NULL, destheader, context);
 	http_handle_close (handle, context);
+	g_free (destheader);
 	handle = NULL;
 
 	if (result == GNOME_VFS_ERROR_NOT_FOUND) {
